@@ -1,4 +1,3 @@
-#' @include parse.R
 #' @include list.R
 #' @include string.R
 #' @include roclet.R
@@ -19,7 +18,9 @@ register.preref.parsers(parse.value,
                         'keywords',
                         'return',
                         'author',
-                        'TODO')
+                        'TODO',
+                        'format',
+                        'source')
 
 register.preref.parsers(parse.name.description,
                         'param',
@@ -57,6 +58,7 @@ register.srcref.parser('setMethod',
 #' \code{@@concept} \tab \code{\\concept}\cr
 #' \code{@@example} \tab \emph{n/a}\cr
 #' \code{@@examples} \tab \code{\\examples}\cr
+#' \code{@@format} \tab \code{\\format}\cr
 #' \code{@@keywords} \tab \code{\\keyword, ...}\cr
 #' \code{@@method} \tab \code{\\method}\cr
 #' \code{@@name} \tab \code{\\name}\cr
@@ -65,6 +67,7 @@ register.srcref.parser('setMethod',
 #' \code{@@references} \tab \code{\\references}\cr
 #' \code{@@return} \tab \code{\\value}\cr
 #' \code{@@seealso} \tab \code{\\seealso}\cr
+#' \code{@@source} \tab \code{\\source}\cr
 #' \code{@@title} \tab \code{\\title}\cr
 #' \code{@@TODO} \tab \emph{n/a}\cr
 #' \code{@@usage} \tab \code{\\usage}\cr
@@ -75,7 +78,7 @@ register.srcref.parser('setMethod',
 #'                        \cite{Writing R Extensions}.}
 #' \item{\code{@@aliases}}{A default alias is plucked from the \code{@@name} or
 #'                         assignee; otherwise, \code{@@alias a b ...} translates
-#'                         to \code{\alias{a}}, \code{\alias{b}}, &c.
+#'                         to \code{\\alias{a}}, \code{\\alias{b}}, &c.
 #'                         If you specify one alias, however, specify them all.}
 #' \item{\code{@@concept}}{See \dQuote{2.8 Indices} from
 #'                         \cite{Writing R Extensions}.}
@@ -84,12 +87,14 @@ register.srcref.parser('setMethod',
 #'                         \file{tests}, for instance, it will be checked with
 #'                         \command{R CMD check}.
 #'                         The contents of the file will
-#'                         be concatenated under \code{\examples{...}}.}
+#'                         be concatenated under \code{\\examples{...}}.}
 #' \item{\code{@@examples}}{Verbatim examples; see \dQuote{2.1.1
 #'                          Documenting functions} from \cite{Writing R
 #'                          Extensions}.}
+#' \item{\code{@@format}}{See \dQuote{2.1.2 Documenting data sets} from
+#'                        \cite{Writing R Extensions}.}
 #' \item{\code{@@keywords}}{\code{@@keywords a b ...} translates to
-#'                          \code{\keyword{a}}, \code{\keyword{b}}, &c.}
+#'                          \code{\\keyword{a}}, \code{\\keyword{b}}, &c.}
 #' \item{\code{@@method}}{Use \code{@@method <generic> <class>} to document
 #'                        S3 functions.}
 #' \item{\code{@@name}}{In the absense of an explicit \code{@@name} tag, the
@@ -103,6 +108,8 @@ register.srcref.parser('setMethod',
 #' \item{\code{@@return}}{The return value of the function, or \code{NULL}.}
 #' \item{\code{@@seealso}}{See \dQuote{2.1.1 Documenting functions} from
 #'                         \cite{Writing R Extensions}.}
+#' \item{\code{@@source}}{See \dQuote{2.1.2 Documenting data sets} from
+#'                        \cite{Writing R Extensions}.}
 #' \item{\code{@@title}}{A default title is plucked from the first sentence
 #'                       of the description; that is, the first phrase ending
 #'                       with a period, question mark or newline.
@@ -146,7 +153,8 @@ register.srcref.parser('setMethod',
 #' @export
 #' @aliases name aliases title usage references concept
 #' note seealso example examples keywords return author
-#' TODO param method setClass setGeneric setMethod
+#' make.Rd.roclet
+#' @TODO param method setClass setGeneric setMethod
 #' make.Rd.roclet
 make.Rd.roclet <- function(subdir=NULL,
                            verbose=TRUE) {
